window.onload = function () {
    // Fetch JSON data from the provided URL
    fetch('https://raw.githubusercontent.com/apan1121/powerInfoV2/gh-pages/log/summary.log')
        .then(response => response.json())
        .then(data => {
            // Call function to create Line Chart
            createLineChart(data);
        })
        .catch(error => console.error('Error fetching data:', error));
};

function createLineChart(data) {
    const canvas = document.getElementById('lineChart');
    const ctx = canvas.getContext('2d');

    // Call function to calculate hourly usage trend
    const diffTrend = calcDiffTrend(data);

    const dates = Object.keys(diffTrend);
    const datasets = [];

    for (const hourMinute in diffTrend[dates[0]]) {
        const values = dates.map(date => diffTrend[date][hourMinute]);
        datasets.push({
            label: hourMinute,
            data: values,
            borderColor: getRandomColor(),
            fill: false,
        });
    }

    new Chart(ctx, {
        type: 'line',
        data: {
            labels: dates,
            datasets: datasets,
        },
        options: {
            responsive: true,
            scales: {
                x: {
                    type: 'category',
                    scaleLabel: {
                        display: true,
                        labelString: '星期幾',
                    },
                },
                y: {
                    scaleLabel: {
                        display: true,
                        labelString: '發電量',
                    },
                },
            },
        },
    });
}

function getRandomColor() {
    const letters = '0123456789ABCDEF';
    let color = '#';
    for (let i = 0; i < 6; i++) {
        color += letters[Math.floor(Math.random() * 16)];
    }
    return color;
}


function calcDiffTrend(data) {
    const limitDateNum = 14;
    const today = parseInt(moment(moment().format('YYYY-MM-DD')).format('x'));
    const tomorraw = parseInt(moment(today).add(1, 'days').format('x'));
    const startDate = moment(today).add((limitDateNum * -1 + 1), 'days').format('YYYY-MM-DD');
    const startDateTimestamp = parseInt(moment(startDate).format('x'));

    const mappingShowWeek = {};
    const thisWeekNum = moment().format('ww');

    for (let dateIndex = 0; dateIndex < limitDateNum; dateIndex += 1) {
        const timestamp = startDateTimestamp + (dateIndex) * 86400000;
        const dateObj = moment(timestamp);
        const date = dateObj.format('YYYY-MM-DD');
        let showWeek = dateObj.format('ddd');
        const weekNum = dateObj.format('ww');
        for (let i = 0; i < (thisWeekNum - weekNum); i += 1) {
            showWeek = `上${showWeek}`;
        }
        mappingShowWeek[date] = showWeek;
    }

    const diffTrend = {};
    const nowTimestamp = moment(moment().format('YYYY-MM-DD HH:mm:00')).format('x') - 600000;
    for (let i = today; i < tomorraw; i += 600000) {
        const hourMinute = moment(i).format('HH:mm');
        diffTrend[hourMinute] = {};

        for (let dateIndex = 0; dateIndex < limitDateNum; dateIndex += 1) {
            const date = moment(startDateTimestamp + dateIndex * 86400000).format('YYYY-MM-DD');
            let used = false;
            const dateTime = `${date} ${hourMinute}`;

            if (moment(`${dateTime}:00`).format('x') < nowTimestamp) {
                used = 0;
                if (data[dateTime]) {
                    const info = JSON.parse(JSON.stringify(data[`${date} ${hourMinute}`]));
                    for (const typeKey in info) {
                        if (!!info[typeKey] && 1) {
                            used += parseFloat(info[typeKey].used);
                        }
                    }
                }
            }

            if (used !== false) {
                const showWeek = mappingShowWeek[date];
                diffTrend[hourMinute][showWeek] = Math.round(used * 100) / 100;
            }
        }
    }
    return